<?php
/*
	Plugin Name: Promotion Calendar
	Plugin URI: http://promotioncalender.com
	Description: Promotion Calendar enables you to easily set up an advent calendar style page in any month with daily offers to grow your email marketing list. 
	Version: 2.1.3
	Author: The Modern Entrepreneur
	Author URI: http://themodernentrepreneur.com
	License: GPL2

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
*/

include 'admin/wppc-settings.php';
require_once('admin/wppc-update-plugin.php');
new WPUpdatesPluginUpdater_769( 'http://wp-updates.com/api/2/plugin', plugin_basename(__FILE__));

$pluginFile = __FILE__;
register_activation_hook($pluginFile, 'wppc_activation');
register_deactivation_hook($pluginFile, 'wppc_deactivation');

if (!function_exists('wppc_activation')) {
    function wppc_activation() {

		global $user_ID;
		
		// Create Promotion Calendar Page
		$wppc_page['post_type']    = 'page';
		$wppc_page['post_content'] = '';
		$wppc_page['post_parent']  = 0;
		$wppc_page['post_author']  = $user_ID;
		$wppc_page['post_status']  = 'publish';
		$wppc_page['post_name']    = 'promotion-calendar';
		$wppc_page['post_title']   = 'Promotion Calendar';
			
		$wppc_pageid = wp_insert_post ($wppc_page);
		
		// Create Promotion Calendar Locked Error Page
		$wppc_error_page['post_type']    = 'page';
		$wppc_error_page['post_content'] = 'This promotion is currently locked but you can still make sure you never miss out on any of our promotions by entering your details below so we can send you exclusive updates on our promotions.';
		$wppc_error_page['post_parent']  = 0;
		$wppc_error_page['post_author']  = $user_ID;
		$wppc_error_page['post_status']  = 'publish';
		$wppc_error_page['post_name']    = 'date-locked';
		$wppc_error_page['post_title']   = 'Grab The Hottest Offers';
			
		$wppc_error_pageid = wp_insert_post ($wppc_error_page);		
		
		global $wpdb;
		
		// Flush Rewrite Rules
		flush_rewrite_rules( $hard );

	}
}

if (!function_exists('wppc_deactivation')) {
    function wppc_deactivation() {
		
		$options = get_option('wppc_display_options');	
		
		$calendar_page_slug = 'promotion-calendar';
		$page = get_page_by_path($calendar_page_slug);
		$wppcID = $page->ID;

		wp_delete_post( $wppcID ); 
		
		
		$error_page_slug = 'date-locked';
		$page = get_page_by_path($error_page_slug);
		$errorID = $page->ID;

		wp_delete_post( $errorID ); 
		
		// Flush Rewrite Rules
		flush_rewrite_rules( $hard );
		
    }
}

/* Define Paths */
if (!defined('WPPC_PLUGIN_NAME'))
    define('WPPC_PLUGIN_NAME', trim(dirname(plugin_basename(__FILE__)), '/'));
 
if (!defined('WPPC_PLUGIN_DIR'))
    define('WPPC_PLUGIN_DIR', WP_PLUGIN_DIR . '/' . WPPC_PLUGIN_NAME);
 
if (!defined('WPPC_PLUGIN_URL'))
    define('WPPC_PLUGIN_URL', WP_PLUGIN_URL . '/' . WPPC_PLUGIN_NAME);
	
/* Admin Scripts and Styles */
function wppc_upload_scripts_enqueue() {
	$plugindir = dirname( __FILE__ );
	
	wp_enqueue_media();
	wp_register_script('upload-bg' , WPPC_PLUGIN_URL . '/admin/upload-bg.js');
	wp_enqueue_script('upload-bg');

}
add_action("admin_enqueue_scripts", "wppc_upload_scripts_enqueue");

/* Front End Scripts and Styles */
add_action("wp_enqueue_scripts", "wppc_scripts_enqueue");
function wppc_scripts_enqueue() {

	wp_register_script('jquery-fancybox' , WPPC_PLUGIN_URL . '/templates/lightbox/jquery.fancybox.js?v=2.1.5', array('jquery'));
	wp_enqueue_script('jquery-fancybox');
	
	wp_register_style('fancybox' , WPPC_PLUGIN_URL . '/templates/lightbox/jquery.fancybox.css?v=2.1.5');
	wp_enqueue_style('fancybox');
	
	$options = get_option('wppc_display_options');	
		
	$calendar_page_slug = $options['wppc_slug'];;
	$indexpage = get_page_by_path($calendar_page_slug);
	$wppcID = $indexpage->ID;
	
	$error_page_slug = $options['wppc_error_slug'];;
	$errorpage = get_page_by_path($error_page_slug);
	$errorID = $errorpage->ID;
		
	if( get_post_type() ==	('promotion') || is_page($wppcID) || is_page($errorID) )  {
		wp_register_style('wppc-css' , WPPC_PLUGIN_URL . '/templates/css/style.css');
		wp_enqueue_style('wppc-css');
	}
}

function add_jquery_ui() {
    wp_enqueue_script( 'jquery-ui-core' );
    wp_enqueue_script( 'jquery-ui-widget' );
    wp_enqueue_script( 'jquery-ui-mouse' );
    wp_enqueue_script( 'jquery-ui-accordion' );
    wp_enqueue_script( 'jquery-ui-autocomplete' );
    wp_enqueue_script( 'jquery-ui-slider' );
    wp_enqueue_script( 'jquery-ui-tabs' );
    wp_enqueue_script( 'jquery-ui-sortable' );
    wp_enqueue_script( 'jquery-ui-draggable' );
    wp_enqueue_script( 'jquery-ui-droppable' );
    wp_enqueue_script( 'jquery-ui-datepicker' );
    wp_enqueue_script( 'jquery-ui-resize' );
    wp_enqueue_script( 'jquery-ui-dialog' );
    wp_enqueue_script( 'jquery-ui-button' );
}
add_action( 'wp_enqueue_scripts', 'add_jquery_ui' );

/* Create Promotion Post Type */
add_action('init', 'register_promotion_cpt');
function register_promotion_cpt() {
register_post_type('promotion', array(
	'label' => 'Promotions',
	'description' => '',
	'public' => true,
	'show_ui' => true,
	'show_in_menu' => true,
	'capability_type' => 'page',
	'map_meta_cap' => true,
	'hierarchical' => false,
	'rewrite' => array('slug' => 'promotion', 'with_front' => 1),
	'query_var' => true,
	'menu_position' => '25',
	'menu_icon' => $pluginicon = WPPC_PLUGIN_URL . '/images/wppc-icon.png',
	'supports' => array('title','editor','excerpt','custom-fields','revisions','thumbnail','author','page-attributes'),
	
	'labels' => array (
		'name' => 'Promotions',
		'singular_name' => 'Promotion',
		'menu_name' => 'My Promotions',
		'add_new' => 'Add New',
		'add_new_item' => 'Add New Promotion',
		'edit' => 'Edit',
		'edit_item' => 'Edit Promotion',
		'new_item' => 'New Promotion',
		'view' => 'View Promotion',
		'view_item' => 'View Promotion',
		'search_items' => 'Search Promotions',
		'not_found' => 'No Promotions Found',
		'not_found_in_trash' => 'No Promotions found in Trash',
		'parent' => 'Parent Promotion',
	) ) ); 
}

/* Hook in Page Template */
add_action('template_redirect', 'wppc_redirect');
function wppc_redirect() {
    global $wp;
    $plugindir = dirname( __FILE__ );
	$options = get_option('wppc_display_options');
	if (!isset($wp->query_vars['post_type'])) {
  		$wp->query_vars['post_type'] = "undefined";
  	} 
  	if (!isset($wp->query_vars['pagename'])) {
  		$wp->query_vars['pagename'] = "undefined";
  	} 

    /* Add Promotion Post Type Template */
    if ($wp->query_vars['post_type'] == 'promotion') {
        $templatefilename = 'wppc-single-promotion.php';
        if (file_exists(TEMPLATEPATH . '/' . $templatefilename)) {
            $return_template = TEMPLATEPATH . '/' . $templatefilename;
        } else {
            $return_template = $plugindir . '/templates/' . $templatefilename;
        }
        do_theme_redirect($return_template);

	/* Add Promotion Calendar Page Template */
    } elseif ($wp->query_vars['pagename'] == $options['wppc_slug']) {
        $templatefilename = 'wppc-index.php';
        if (file_exists(TEMPLATEPATH . '/' . $templatefilename)) {
            $return_template = TEMPLATEPATH . '/' . $templatefilename;
        } else {
            $return_template = $plugindir . '/templates/' . $templatefilename;
        }
        do_theme_redirect($return_template);
		
	/* Add Promotion Calendar Error Page Template */
    } elseif ($wp->query_vars['pagename'] == $options['wppc_error_slug']) {
        $templatefilename = 'wppc-locked-promotion.php';
        if (file_exists(TEMPLATEPATH . '/' . $templatefilename)) {
            $return_template = TEMPLATEPATH . '/' . $templatefilename;
        } else {
            $return_template = $plugindir . '/templates/' . $templatefilename;
        }
        do_theme_redirect($return_template);
    } 
}

function do_theme_redirect($url) {
    global $post, $wp_query;
    if (have_posts()) {
        include($url);
        die();
    } else {
        $wp_query->is_404 = true;
    }
}

function wppc_activecampaign_optin() { 

	// Import ActiveCampaign Connection Details
	$options = get_option('wppc_display_options');
	$api_url = $options['wppc_activecampaign_url'];
	$api_key = $options['wppc_activecampaign_api'];
	$api_form = $options['wppc_activecampaign_form'];
	
	// Manually Add API Details
	define("API_URL", $api_url);
	define("API_KEY", $api_key );

	// Initiate ActiveCampaign Scripts
	require_once("includes/activecampaign/ActiveCampaign.class.php");
	$ac = new ActiveCampaign(API_URL, API_KEY);
	
	$form_embed_params = array(
		"id" => $api_form,
		"ajax" => 0,
		"css" => 0,
	);
	
	// perform sync via add/edit
	$sync = 1;

	
	$api_params = array();
	foreach ($form_embed_params as $var => $val) {
		$api_params[] = $var . "=" . $val;
	}
	
	
	$form_html = $ac->api("form/embed?" . implode("&", $api_params));
	
	?> 	
		<div id="wppc-default-optin">
		<h3><?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_headline']; ?></h3>
	<?php
	
	echo $form_html;
	
	?> 
	<p><span><?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_privacy_text']; ?></span></p>
	</div>
	<?php

}

function wppc_aweber_optin() { 
	?>
	<div id="wppc-default-optin">
		<h3><?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_headline']; ?></h3>
			<form method="post" action="http://www.aweber.com/scripts/addlead.pl" style="margin-left:5%;">
			<div style="display: none;">
				<input type="hidden" name="listname" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_aweber_id']; ?>" />
				<input type="hidden" name="redirect" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_aweber_redirect']; ?>" />
				<input type="hidden" name="meta_redirect_onlist" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_aweber_redirect']; ?>" />
				<input type="hidden" name="meta_adtracking" value="promotion-calendar" />
				<input type="hidden" name="meta_message" value="1" />
				<input type="hidden" name="meta_required" value="email" />
				<input type="hidden" name="meta_tooltip" value="" />
			</div>

			<p>
				<input type="text" name="name" class="name" value="Your name..." onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;" tabindex="501" />
				<input type="email" name="email" class="email" value="Your email..." onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;" tabindex="502" />
			</p>
			<p>
				<input name="submit" type="submit" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_button_text']; ?>" tabindex="503" />
				<span><?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_privacy_text']; ?></span>
			</p>
		</form>
	</div>
	<?php 
}

function wppc_mailchimp_optin() {
	?>
		<div id="wppc-default-optin">
			<h3><?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_headline']; ?></h3>
			<form action="<?php $options = get_option('wppc_display_options'); echo $options['wppc_mailchimp_form_action']; ?>" method="post" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form" class="validate" target="_blank">

				<input type="hidden" name="u" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_mailchimp_user_id']; ?>">
				<input type="hidden" name="id" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_mailchimp_list_id']; ?>">

				<input type="text" size="30" value="Your name..." name="<?php $options = get_option('wppc_display_options'); echo $options['wppc_mailchimp_name_input']; ?>" class="name" id="mce-FNAME" onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;">
				<input type="email" size="30" value="Your email..." name="<?php $options = get_option('wppc_display_options'); echo $options['wppc_mailchimp_email_input']; ?>" class="required email" id="mce-EMAIL" onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;">

				<div id="mce-responses" class="clear">
					<div class="response" id="mce-error-response" style="display:none"></div>
					<div class="response" id="mce-success-response" style="display:none"></div>
				</div>

				<div style="clear:both;">
					<input type="submit" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_button_text']; ?>" name="subscribe" id="mc-embedded-subscribe" class="button">
				</div>
				<span><?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_privacy_text']; ?></span>
			</form>
		</div>
	<?php
}

function wppc_getresponse_optin() {
	?>
		<div id="wppc-default-optin">
			<h3><?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_headline']; ?></h3>
			<form accept-charset="utf-8" action="https://app.getresponse.com/add_contact_webform.html" method="post"> 
				<p>
					<input class="name" type="text" name="name" value="Your name..." onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;" tabindex="500" tabindex="900" />
					<input class="email" type="text" name="email" value="Your email..." onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;" tabindex="901" />
				</p>
				<p>
					<input type="submit" name="submit" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_button_text']; ?>" tabindex="902" />
				</p>
				<input type="hidden" name="webform_id" value="<?php $options = get_option('wppc_display_options'); echo $options['wppc_getresponse_id']; ?>"/>
			</form>
			<span><?php $options = get_option('wppc_display_options'); echo $options['wppc_optin_privacy_text']; ?></span>
			<script type="text/javascript" src="<?php $options = get_option('wppc_display_options'); echo 'https://app.getresponse.com/view_webform.js?wid=' . $options['wppc_getresponse_id'] . '&mg_param1=1'; ?>"></script>
		</div>
	<?php
}

?>